@@ -24,24 +24,19 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 */
 
-#ifdef HAVE_LIBEXIF
-#include <libexif/exif-data.h>
-#endif
-
-#ifdef HAVE_LIBCURL
-#include <curl/curl.h>
-#endif
-
 #include "feh.h"
 #include "filelist.h"
 #include "signals.h"
 #include "options.h"
 
+#ifdef HAVE_LIBCURL
+#include <curl/curl.h>
+#endif
+
 gib_list *filelist = NULL;
 gib_list *original_file_items = NULL; /* original file items from argv */
 int filelist_len = 0;
 gib_list *current_file = NULL;
-extern int errno;
 
 static gib_list *rm_filelist = NULL;
 
@@ -160,7 +155,7 @@ static void feh_print_stat_error(char *path)
 	}
 }
 
-static void add_stdin_to_filelist()
+static void add_stdin_to_filelist(void)
 {
 	char buf[1024];
 	size_t readsize;
@@ -202,7 +197,7 @@ void add_file_to_filelist_recursively(char *origpath, unsigned char level)
 	struct stat st;
 	char *path;
 
-	if (!origpath)
+	if (!origpath || *origpath == '\0')
 		return;
 
 	path = estrdup(origpath);
@@ -645,7 +640,7 @@ char *feh_absolute_path(char *path)
 	   filelist file can be saved anywhere and feh will still find the
 	   images */
 	D(("Need to convert %s to an absolute form\n", path));
-	/* I SHOULD be able to just use a simple realpath() here, but dumb * 
+	/* I SHOULD be able to just use a simple realpath() here, but dumb *
 	   old Solaris's realpath doesn't return an absolute path if the
 	   path you give it is relative. Linux and BSD get this right... */
 	if (getcwd(cwd, sizeof(cwd)) == NULL)
@@ -661,7 +656,7 @@ char *feh_absolute_path(char *path)
 	return(ret);
 }
 
-void feh_save_filelist()
+void feh_save_filelist(void)
 {
 	char *tmpname;
 	char *base_dir = "";
