@@ -593,7 +593,7 @@ int feh_thumbnail_get_thumbnail(Imlib_Image * image, feh_file * file,
 	return status;
 }
 
-static char *feh_thumbnail_get_prefix()
+static char *feh_thumbnail_get_prefix(void)
 {
 	char *dir = NULL, *home, *xdg_cache_home;
 
@@ -636,9 +636,9 @@ char *feh_thumbnail_get_name_uri(char *name)
 	/* FIXME: what happens with http, https, and ftp? MTime etc */
 	if (!path_is_url(name)) {
 
-		/* make sure it's an absoulte path */
+		/* make sure it's an absolute path */
 		/* FIXME: add support for ~, need to investigate if it's expanded
-		   somewhere else before adding (unecessary) code */
+		   somewhere else before adding (unnecessary) code */
 		if (name[0] != '/') {
 			/* work around /some/path/./image.ext */
 			if ((strncmp(name, "./", 2)) == 0)
@@ -882,13 +882,13 @@ void feh_thumbnail_select_prev(winwidget winwid, int jump)
 	}
 }
 
-void feh_thumbnail_show_selected()
+void feh_thumbnail_show_selected(void)
 {
 	if (td.selected && td.selected->file)
 		feh_thumbnail_show_fullsize(td.selected->file);
 }
 
-feh_file* feh_thumbnail_get_selected_file()
+feh_file* feh_thumbnail_get_selected_file(void)
 {
 	if (td.selected)
 		return td.selected->file;
